Contact
=======

If you have any questions, suggestions, or need support, feel free to reach out.

### Nathan Ramos, CFA

Welcome to my GitHub! I'm Nathan, a Fintech Developer with a Chartered Financial
Analyst (CFA) designation, specializing in Python-based financial analysis,
quantitative strategies, and automated trading programs. Currently, I'm a
fintech consultant open to new clients, especially in the realm of automated
trading algorithms.

📅 **`Schedule a Meeting with Me <https://calendly.com/nrcapitalmanagement/github-meeting>`_**

### Connect with Me

- **Email**: `nathan.ramos.github@gmail.com <mailto:nathan.ramos.github@gmail.com>`_
- **Twitter**: `@nathanramoscfa <https://twitter.com/nathanramoscfa>`_

Feel free to connect with me for any inquiries or collaboration opportunities.
